==> igniteui-webcomponents-core-1.4.2.tgz: package/esm5/lib/MathUtil.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
/**
 * @hidden
 */
var MathUtil = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(MathUtil, _super);
    function MathUtil() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MathUtil.a = function (a) {
        return Math.log(a + Math.sqrt(a * a + 1));
    };
    MathUtil.p = function (number_) {
        return number_.toString();
    };
    MathUtil.e = function (a, b) {
        return Math.sqrt(a * a + b * b);
    };
    MathUtil.n = function (a) {
        return a * a;
    };
    MathUtil.b = function (a, b, c) {
        return Math.min(c, Math.max(b, a));
    };
    MathUtil.m = function (a) {
        return Math.PI * a / 180;
    };
    MathUtil.d = function (a) {
        return 180 * a / Math.PI;
    };
    MathUtil.j = function (a, b, c) {
        return Math.min(a, Math.min(b, c));
    };
    MathUtil.g = function (a, b, c) {
        return Math.max(a, Math.max(b, c));
    };
    MathUtil.i = function () {
        var a = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            a[_i] = arguments[_i];
        }
        var b = a[0];
        for (var c = 1; c < a.length; ++c) {
            b = Math.min(b, a[c]);
        }
        return b;
    };
    MathUtil.k = function (a) {
        var b = a[0];
        for (var c = 1; c < a.length; ++c) {
            b = Math.min(b, a[c]);
        }
        return b;
    };
    MathUtil.f = function () {
        var a = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            a[_i] = arguments[_i];
        }
        var b = a[0];
        for (var c = 1; c < a.length; ++c) {
            b = Math.max(b, a[c]);
        }
        return b;
    };
    MathUtil.h = function (a) {
        var b = a[0];
        for (var c = 1; c < a.length; ++c) {
            b = Math.max(b, a[c]);
        }
        return b;
    };
    MathUtil.$t = markType(MathUtil, 'MathUtil');
    MathUtil.l = (1 + Math.sqrt(5)) / 2;
    MathUtil.o = Math.sqrt(2);
    return MathUtil;
}(Base));
export { MathUtil };

==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/MathUtil.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { isNaN_, isInfinity } from "./number";
/**
 * @hidden
 */
var MathUtil = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(MathUtil, _super);
    function MathUtil() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MathUtil.a = function (a) {
        return Math.log(a + Math.sqrt(a * a + 1));
    };
    MathUtil.r = function (number_) {
        return number_.toString();
    };
    MathUtil.f = function (a, b) {
        return Math.sqrt(a * a + b * b);
    };
    MathUtil.o = function (a) {
        return a * a;
    };
    MathUtil.c = function (a, b, c) {
        return Math.min(c, Math.max(b, a));
    };
    MathUtil.n = function (a) {
        return Math.PI * a / 180;
    };
    MathUtil.e = function (a) {
        return 180 * a / Math.PI;
    };
    MathUtil.k = function (a, b, c) {
        return Math.min(a, Math.min(b, c));
    };
    MathUtil.h = function (a, b, c) {
        return Math.max(a, Math.max(b, c));
    };
    MathUtil.j = function () {
        var a = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            a[_i] = arguments[_i];
        }
        var b = a[0];
        for (var c = 1; c < a.length; ++c) {
            b = Math.min(b, a[c]);
        }
        return b;
    };
    MathUtil.l = function (a) {
        var b = a[0];
        for (var c = 1; c < a.length; ++c) {
            b = Math.min(b, a[c]);
        }
        return b;
    };
    MathUtil.g = function () {
        var a = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            a[_i] = arguments[_i];
        }
        var b = a[0];
        for (var c = 1; c < a.length; ++c) {
            b = Math.max(b, a[c]);
        }
        return b;
    };
    MathUtil.i = function (a) {
        var b = a[0];
        for (var c = 1; c < a.length; ++c) {
            b = Math.max(b, a[c]);
        }
        return b;
    };
    MathUtil.q = function (a) {
        if (a.length == 0) {
            return 0;
        }
        var b = 0;
        for (var d = 0; d < a.length; d++) {
            var c = a[d];
            if (isNaN_(c)) {
                continue;
            }
            if (isInfinity(c)) {
                continue;
            }
            b += c;
        }
        return b;
    };
    MathUtil.b = function (a) {
        if (a.length == 0) {
            return 0;
        }
        var b = 0;
        var c = 0;
        for (var e = 0; e < a.length; e++) {
            var d = a[e];
            if (isNaN_(d)) {
                continue;
            }
            if (isInfinity(d)) {
                continue;
            }
            b += d;
            c++;
        }
        return b / c;
    };
    MathUtil.$t = markType(MathUtil, 'MathUtil');
    MathUtil.m = (1 + Math.sqrt(5)) / 2;
    MathUtil.p = Math.sqrt(2);
    return MathUtil;
}(Base));
export { MathUtil };
